@@ -89,14 +89,14 @@ impl Display for UnaffectedRange {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match &self.start {
             Bound::Unbounded => f.write_str("[0"),
-            Bound::Exclusive(v) => f.write_fmt(format_args!("({}", v)),
-            Bound::Inclusive(v) => f.write_fmt(format_args!("[{}", v)),
+            Bound::Exclusive(v) => f.write_fmt(format_args!("({v}")),
+            Bound::Inclusive(v) => f.write_fmt(format_args!("[{v}")),
         }?;
         f.write_str(", ")?;
         match &self.end {
             Bound::Unbounded => f.write_str("∞)"),
-            Bound::Exclusive(v) => f.write_fmt(format_args!("{})", v)),
-            Bound::Inclusive(v) => f.write_fmt(format_args!("{}]", v)),
+            Bound::Exclusive(v) => f.write_fmt(format_args!("{v})")),
+            Bound::Inclusive(v) => f.write_fmt(format_args!("{v}]")),
         }
     }
 }
